@@ -4,13 +4,13 @@ use strict;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common 2.093 qw(:Status);
-use Compress::Raw::Zlib  2.093 qw( !crc32 !adler32 ) ;
-                                  
-require Exporter;                                     
+use IO::Compress::Base::Common 2.101 qw(:Status);
+use Compress::Raw::Zlib  2.101 qw( !crc32 !adler32 ) ;
+
+require Exporter;
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, @EXPORT, %DEFLATE_CONSTANTS);
 
-$VERSION = '2.093';
+$VERSION = '2.102';
 @ISA = qw(Exporter);
 @EXPORT_OK = @Compress::Raw::Zlib::DEFLATE_CONSTANTS;
 %EXPORT_TAGS = %Compress::Raw::Zlib::DEFLATE_CONSTANTS;
@@ -24,20 +24,20 @@ sub mkCompObject
     my $level    = shift ;
     my $strategy = shift ;
 
-    my ($def, $status) = new Compress::Raw::Zlib::Deflate
+    my ($def, $status) = Compress::Raw::Zlib::Deflate->new(
                                 -AppendOutput   => 1,
                                 -CRC32          => $crc32,
                                 -ADLER32        => $adler32,
                                 -Level          => $level,
                                 -Strategy       => $strategy,
-                                -WindowBits     => - MAX_WBITS;
+                                -WindowBits     => - MAX_WBITS);
 
-    return (undef, "Cannot create Deflate object: $status", $status) 
-        if $status != Z_OK;    
+    return (undef, "Cannot create Deflate object: $status", $status)
+        if $status != Z_OK;
 
     return bless {'Def'        => $def,
                   'Error'      => '',
-                 } ;     
+                 } ;
 }
 
 sub compr
@@ -51,11 +51,11 @@ sub compr
 
     if ($status != Z_OK)
     {
-        $self->{Error} = "Deflate Error: $status"; 
+        $self->{Error} = "Deflate Error: $status";
         return STATUS_ERROR;
     }
 
-    return STATUS_OK;    
+    return STATUS_OK;
 }
 
 sub flush
@@ -70,11 +70,11 @@ sub flush
 
     if ($status != Z_OK)
     {
-        $self->{Error} = "Deflate Error: $status"; 
+        $self->{Error} = "Deflate Error: $status";
         return STATUS_ERROR;
     }
 
-    return STATUS_OK;        
+    return STATUS_OK;
 }
 
 sub close
@@ -97,14 +97,14 @@ sub reset
     $self->{ErrorNo} = $status;
     if ($status != Z_OK)
     {
-        $self->{Error} = "Deflate Error: $status"; 
+        $self->{Error} = "Deflate Error: $status";
         return STATUS_ERROR;
     }
 
-    return STATUS_OK;    
+    return STATUS_OK;
 }
 
-sub deflateParams 
+sub deflateParams
 {
     my $self = shift ;
 
@@ -114,11 +114,11 @@ sub deflateParams
     $self->{ErrorNo} = $status;
     if ($status != Z_OK)
     {
-        $self->{Error} = "deflateParams Error: $status"; 
+        $self->{Error} = "deflateParams Error: $status";
         return STATUS_ERROR;
     }
 
-    return STATUS_OK;   
+    return STATUS_OK;
 }
 
 
@@ -167,4 +167,3 @@ sub adler32
 1;
 
 __END__
-
